@@ -1,4 +1,4 @@
-# !/usr/bin/env python
+#! /usr/bin/env python
 # -*- coding: utf-8 -*-
 # Pedro Gabaldon
 
@@ -8,6 +8,15 @@ import os
 delete = DeleteKey(HKEY_CLASSES_ROOT, "Directory\\Background\\shell\\Remove Drive access\\command")
 delete = DeleteKey(HKEY_CLASSES_ROOT, "Directory\\Background\\shell\\Remove Drive access")
 
+delete = DeleteKey(HKEY_CLASSES_ROOT, "Directory\\Background\\shell\\List drive files\\command")
+delete = DeleteKey(HKEY_CLASSES_ROOT, "Directory\\Background\\shell\\List drive files")
+
+delete = DeleteKey(HKEY_CLASSES_ROOT, "Directory\\Background\\shell\\Drive download here\\command")
+delete = DeleteKey(HKEY_CLASSES_ROOT, "Directory\\Background\\shell\\Drive download here")
+
+delete = DeleteKey(HKEY_CLASSES_ROOT, "Directory\\Background\\shell\\Move Drive files/folders\\command")
+delete = DeleteKey(HKEY_CLASSES_ROOT, "Directory\\Background\\shell\\Move Drive files/folders")
+
 delete = DeleteKey(HKEY_CLASSES_ROOT, "Directory\\Background\\shell\\New Drive folder\\command")
 delete = DeleteKey(HKEY_CLASSES_ROOT, "Directory\\Background\\shell\\New Drive folder")
 
